@@ -54,7 +54,7 @@ class MetaFetcher:
     def subresources_metadata_types(self) -> list[str]:
         return list(SUBRESOURCES_METAMAP.keys())
 
-    def fetch(self, metadata_type: str, region_name: str, required_filters: Optional[list[dict[str, Any]]] = None) -> Iterator[dict[str, Any]]:
+    def fetch(self, metadata_type: str, region_name: str, required_filters: Optional[list[dict[str, Any]]] = None, custom_kwargs: Optional[dict[str, Any]] = None) -> Iterator[dict[str, Any]]:
         metadata_config = self.metadata_config(metadata_type)
         call_kwargs = thaw(metadata_config.get("kwargs", {}))
         kwargs_list = []
@@ -62,11 +62,13 @@ class MetaFetcher:
         if "parent_required_filters" in metadata_config:
             for filter_kwargs in (required_filters or []):
                 kwargs_list.append(dict(call_kwargs, **filter_kwargs))
+        elif custom_kwargs:
+            kwargs_list.append(custom_kwargs)
         else:
             kwargs_list.append(call_kwargs)
 
         for kwargs in kwargs_list:
-            yield from resource_listing(
+            fetched_resources = resource_listing(
                 session=self.session,
                 metaname=metadata_type,
                 fetch_method=metadata_config["fetch_method"],
@@ -75,3 +77,4 @@ class MetaFetcher:
                 call_kwargs=kwargs,
                 region_name=region_name,
             )
+            yield from (dict(resource, **kwargs) for resource in fetched_resources)
