@@ -40,6 +40,7 @@ METAMAP = freeze(
         "iam_account_aliases": {"fetch_method": "list_account_aliases", "response_key": "AccountAliases"},
         "iam_account_summary": {"fetch_method": "get_account_summary", "response_key": "SummaryMap"},
         "iam_account_password_policy": {"fetch_method": "get_account_password_policy", "response_key": "PasswordPolicy"},
+        "iam_instance_profiles": {"fetch_method": "list_instance_profiles", "response_key": "InstanceProfiles"},
         "iam_roles": {"fetch_method": "list_roles", "response_key": "Roles"},
         "iam_users": {"fetch_method": "list_users", "response_key": "Users"},
         "inspector_assessment_runs": {"fetch_method": "list_assessment_runs", "response_key": "assessmentRunArns"},
@@ -73,6 +74,13 @@ SUBRESOURCES_METAMAP = freeze(
     })
 )
 
+# This dict stores the "metadata_type -> fields to process" mapping
+# We need it because sweet boto3 lib marks AssumeRolePolicyDocument as str in schemas, but in fact it returns dict obj.
+# SEE: nops_metadata.utils.process_element
+APPLY_NESTED_ELEMENT_PROCESSING = {
+    "iam_instance_profiles": ["Roles"]
+}
+
 RELATIONSHIPS_MAPPING = freeze(
     {
         "ec2_instances": {
