@@ -1,12 +1,15 @@
 import json
 from string import capwords
 from typing import Any
+from typing import Optional
 from typing import Iterator
 
 import boto3
 from botocore.paginate import Paginator
 from pyrsistent import thaw
 
+from nops_metadata.constants import APPLY_NESTED_ELEMENT_PROCESSING
+
 
 def _extract_keyed_page(page: dict, page_key: str, response_key: str) -> Iterator[dict[str, Any]]:
     keyed_page = page[page_key]
@@ -40,7 +43,18 @@ def _handle_page(page: dict, page_key: str, response_key: str) -> Iterator[dict[
             yield page_iter
 
 
-def process_element(element):
+def process_element_list(input_list):
+    for item in input_list:
+        if "AssumeRolePolicyDocument" in item:
+            item = process_element(item)
+
+
+def process_element(element, metadata_type: Optional[str] = None):
+    for field in APPLY_NESTED_ELEMENT_PROCESSING.get(metadata_type, []):
+        if isinstance(element[field], list):
+            process_element_list(element[field])
+        # TODO: Add process_element_dict once it needed
+
     if "AssumeRolePolicyDocument" in element:
         element["AssumeRolePolicyDocument"] = json.dumps(element["AssumeRolePolicyDocument"])
     return element
@@ -67,7 +81,7 @@ def resource_listing(
 
         for page in paginator.paginate(**thaw(call_kwargs)):
             for element in _handle_page(page=page, page_key=page_key, response_key=response_key):
-                yield process_element(element)
+                yield process_element(element, metadata_type=metaname)
     else:
         response: list[dict] = getattr(client, fetch_method)(**call_kwargs)[response_key]
         if isinstance(response, list):
